@@ -6,7 +6,8 @@ pkgFileExt <- function(type) {
     "mac.binary" = ".tgz",
     "mac.binary.mavericks" = ".tgz",
     "mac.binary.leopard" = ".tgz",
-    stop("Type ", type, "not recognised.")
+    "mac.binary.el-capitan" = ".tgz",
+    stop("Type ", type, " not recognised.")
   )
 }
 
@@ -58,7 +59,8 @@ addPackageListing <- function(pdb = pkgAvail(), dcf, warnings = TRUE) {
   #   pkgRow <- match(pkgName, rownames(pdb))
   pkgRow <- match(pkgName, pdb[, "Package"])
   newRow <- with(dcf,
-                 c(Package, Version, NA, Depends, Imports, LinkingTo, Suggests, Enhances, License,
+                 c(Package, Version, NA, 
+                   Depends, Imports, LinkingTo, Suggests, Enhances, License,
                    rep(NA, 8)))
   if (!is.na(pkgRow)) {
     pdb[pkgRow, ] <- newRow
@@ -74,8 +76,8 @@ addPackageListing <- function(pdb = pkgAvail(), dcf, warnings = TRUE) {
 
 
 
-# from http://stackoverflow.com/questions/13163248
-# Possible to override the blocking of a package's (re-)installation after it has been required/loaded?
+# from http://stackoverflow.com/questions/13163248 Possible to override the
+# blocking of a package's (re-)installation after it has been required/loaded?
 
 #' @importFrom httr GET stop_for_status content
 readDescriptionGithub <- function(repo, username, branch = "master", quiet = TRUE) {
@@ -95,18 +97,24 @@ readDescriptionGithub <- function(repo, username, branch = "master", quiet = TRU
 
 #' Add DESCRIPTION information from package on github.
 #'
-#' Downloads the DESCRIPTION file from a package on github, parses the fields and adds (or replaces) a row in the available package database.
+#' Downloads the DESCRIPTION file from a package on github, parses the fields
+#' and adds (or replaces) a row in the available package database.
 #'
-#' @param pdb Package database, usually the result of [pkgAvail()] or [available.packages()]
-#' @param repo Character vector. Name of repository on github, e.g. `"RevolutionAnalytics/checkpoint"`
-#' @param username Optional character vector. Name of repository on github, e.g. `"RevolutionAnalytics/checkpoint"``
+#' @param pdb Package database, usually the result of [pkgAvail()] or
+#'   [available.packages()]
+#' @param repo Character vector. Name of repository on github, e.g.
+#'   `"andrie/rrd"`
+#' @param username Optional character vector. Name of repository on github, e.g.
+#'   `"andrie/rrd"`
 #' @param branch name of branch, defaults to `"master"`
 
 #' @export
 #' @family github functions
 #'
 #' @example /inst/examples/example_addPackageListingGithub.R
-addPackageListingGithub <- function(pdb = pkgAvail(), repo, username = NULL, branch = "master") {
+addPackageListingGithub <- function(
+  pdb = pkgAvail(), repo, username = NULL, branch = "master"
+) {
   desc <- readDescriptionGithub(repo = repo, username = username, branch = branch)
   addPackageListing(pdb, desc)
 }
