@@ -3,9 +3,9 @@
 
 .onLoad <- function(libname, pkgname) {
   mran.url <- if (getRversion() >= "3.2.2") {
-    "https://mran.microsoft.com" ## use HTTPS
+    "https://cran.microsoft.com" ## use HTTPS
   } else {
-    "http://mran.microsoft.com" ## use HTTP
+    "http://cran.microsoft.com" ## use HTTP
   }
 
   ## set options using the approach used by devtools
