@@ -35,8 +35,15 @@ for (pkg_type in (types)) {
     prefix <- repoPrefix(pkg_type, Rversion = rvers)
     dir.create(repo_root, recursive = TRUE, showWarnings = FALSE)
 
-    ret <- makeRepo(pkgList, path = repo_root, repos = revolution,
-                    type = pkg_type, quiet = TRUE, Rversion = rvers)
+    with_mock(
+      download_packages = mock_download_packages,
+      write_packages = mock_write_packages,
+      .env = "miniCRAN",
+      {
+        ret <- makeRepo(pkgList, path = repo_root, repos = revolution,
+                        type = pkg_type, quiet = TRUE, Rversion = rvers)
+      }
+    )
 
     expect_is(ret, "character")
     expect_equal(length(ret), length(pkgList))
